/**
 * DevExtreme (esm/ui/scheduler/appointments/resizing/utils.js)
 * Version: 21.2.5 (build 22040-1134)
 * Build date: Wed Feb 09 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
import timeZoneUtils from "../../utils.timeZone";
import {
    createAppointmentAdapter
} from "../../appointmentAdapter";
import {
    getRecurrenceProcessor
} from "../../recurrence";
var normalizeDate = (options, date, sourceDate, isStartDate) => {
    if (!options.considerTime) {
        return date
    }
    var result = new Date(date);
    result.setHours(sourceDate.getHours(), sourceDate.getMinutes(), sourceDate.getSeconds());
    var {
        startDayHour: startDayHour,
        endDayHour: endDayHour,
        appointmentSettings: {
            allDay: allDay
        }
    } = options;
    var minDate = new Date(date);
    var maxDate = new Date(date);
    minDate.setHours(startDayHour, 0, 0, 0);
    maxDate.setHours(endDayHour, 0, 0, 0);
    var isDateOutInterval = isStartDate ? result < minDate.getTime() || result >= maxDate.getTime() : result <= minDate.getTime() || result > maxDate.getTime();
    if (isDateOutInterval) {
        result = !allDay ? maxDate : minDate
    }
    return result
};
var applyTimeZone = (sourceAppointment, startDate, endDate) => timeZoneUtils.getTimezoneOffsetChangeInMs(sourceAppointment.startDate, sourceAppointment.endDate, startDate, endDate);
export var getEndResizeAppointmentStartDate = (options, startDate) => {
    var result = startDate;
    var {
        appointmentSettings: {
            allDay: allDay,
            info: {
                sourceAppointment: sourceAppointment
            }
        },
        timeZoneCalculator: timeZoneCalculator,
        dataAccessors: dataAccessors,
        handles: handles
    } = options;
    var appointmentAdapter = createAppointmentAdapter(sourceAppointment, dataAccessors, timeZoneCalculator);
    var recurrenceProcessor = getRecurrenceProcessor();
    var {
        recurrenceRule: recurrenceRule,
        startDateTimeZone: startDateTimeZone
    } = appointmentAdapter;
    var isRecurrent = recurrenceProcessor.isValidRecurrenceRule(recurrenceRule);
    if (!handles.top && !isRecurrent && !allDay) {
        result = timeZoneCalculator.createDate(startDate, {
            appointmentTimeZone: startDateTimeZone,
            path: "toGrid"
        })
    }
    return result
};
export var normalizeStartDate = (options, startDate, sourceStartDate) => {
    var {
        appointmentSettings: {
            info: {
                sourceAppointment: sourceAppointment
            }
        }
    } = options;
    var normalizedStartDate = normalizeDate(options, startDate, sourceStartDate, true);
    var timeZoneOffset = applyTimeZone(sourceAppointment, normalizedStartDate, sourceAppointment.endDate);
    return new Date(normalizedStartDate.getTime() + timeZoneOffset)
};
export var normalizeEndDate = (options, endDate, sourceEndDate) => {
    var {
        appointmentSettings: {
            info: {
                sourceAppointment: sourceAppointment
            }
        }
    } = options;
    var normalizedEndDate = normalizeDate(options, endDate, sourceEndDate, false);
    var timeZoneOffset = applyTimeZone(sourceAppointment, sourceAppointment.startDate, normalizedEndDate);
    return new Date(normalizedEndDate.getTime() + timeZoneOffset)
};
